@@ -2,8 +2,8 @@
 #' Quality Control of daily precipitation observations
 
 #' @description This function apply several threshold-based criteria to filter original observations of daily precipitation.
-#' @param prec matrix or data.frame containing the original precipitation data. Each column represents one station. The names of columns have to be names of the stations.
-#' @param sts matrix or data.frame. A column "ID" (unique ID of stations) is required. The rest of the columns (all of them) will act as predictors of the model.
+#' @param prec matrix containing the original precipitation data. Each column represents one station. The names of columns have to be names of the stations.
+#' @param sts data.frame. A column "ID" (unique ID of stations) is required. The rest of the columns (all of them) will act as predictors of the model.
 #' @param crs character. Coordinates system in EPSG format (e.g.: "EPSG:4326").
 #' @param coords vector of two character elements. Names of the fields in "sts" containing longitude and latitude.
 #' @param coords_as_preds logical. If TRUE (default), "coords" are also taken as predictors.
@@ -63,7 +63,7 @@ qcPrec <- function (prec, sts, crs, coords, coords_as_preds = TRUE, neibs = 10,
     message(paste0('[',Sys.time(),'] -', " Iteration ", it, " of quality control"))
     
     a <- foreach(j = 1:nrow(a), .combine=cbind, .export=c("qcFirst")) %dopar% {
-         qcFirst(x = a[j,], 
+         qcFirst(x = as.numeric(a[j,]), 
               it = it, 
               sts = sts[,-which(colnames(sts)=='ID')], 
               neibs = neibs,
@@ -83,15 +83,19 @@ qcPrec <- function (prec, sts, crs, coords, coords_as_preds = TRUE, neibs = 10,
       seguir <- 0
     }
   }
-  a <- a[,1:(ncol(a)-1)]
-  rownames(a) <- NULL
+  if(nrow(a)==1){
+    a <- t(as.matrix(a[,1:(ncol(a)-1)]))
+  } else{
+    a <- a[,1:(ncol(a)-1)]
+    rownames(a) <- NULL
+    }
   
   #last iteration
   message(paste0('[',Sys.time(),'] -', "Last iteration of quality control"))
   
   b <- foreach(j = 1:nrow(a), .combine=cbind, .export=c("qcLast")) %dopar% {
-    qcLast(x = a[j,], 
-           y = prec[j,],
+    qcLast(x = as.numeric(a[j,]), 
+           y = as.numeric(prec[j,]),
            sts = sts[,-which(colnames(sts)=='ID')], 
            neibs = neibs,
            coords = coords,
@@ -100,10 +104,15 @@ qcPrec <- function (prec, sts, crs, coords, coords_as_preds = TRUE, neibs = 10,
            thres = thres,
            qc = qc, qc3 = qc3, qc4 = qc4, qc5 = qc5)
   }
-  cleaned <- t(b[1:nrow(sts),])
-  rownames(cleaned) <- NULL
-  codes <- t(b[(nrow(sts)+1):nrow(b),])
-  rownames(codes) <- NULL
+ if(is.numeric(b)){
+    cleaned <- b[1:nrow(sts)]
+    codes <- b[(nrow(sts)+1):length(b)]
+  } else{
+    cleaned <- t(b[1:nrow(sts),])
+    rownames(cleaned) <- NULL
+    codes <- t(b[(nrow(sts)+1):nrow(b),])
+    rownames(codes) <- NULL
+  }
   
   message(paste0('[',Sys.time(),'] -', " End"))
   
